@@ -1,7 +1,8 @@
 from django.conf import settings
 from django.contrib.auth.backends import ModelBackend
+from ground_soil.lang import import_from_string
 from eggplant.constants.settings import USER_TOKEN_CLASS
-from eggplant.utils import import_from_string
+
 
 class TokenBackend(ModelBackend):
     def authenticate(self, token=None):
@@ -13,4 +14,4 @@ class TokenBackend(ModelBackend):
         if user_token_handler.validator(token):
             return user_token_handler.user_from_token(token)
         else:
-            return None
\ No newline at end of file
+            return None
