@@ -16,8 +16,9 @@ limitations under the License.
 
 from django.conf import settings
 from django.core.cache import cache
+from ground_soil.lang import import_from_string
 from eggplant.constants.settings import PERMISSION_DICT as PERMISSION_DICT_KEY
-from eggplant.utils import import_from_string
+
 
 class _Permission(object):
     _PERMISSION_DICT_PATH = getattr(settings, PERMISSION_DICT_KEY, 'eggplant.constants.defaults.PERMISSION_DICT')
@@ -33,7 +34,7 @@ class _Permission(object):
         _reverse_table = cache.get(self._REVERSE_TABLE_CACHE_KEY)
         if _reverse_table is None:
             _reverse_table = dict([(v, k) for (k, v) in self._permissions.items()])
-            cache.set(self._REVERSE_TABLE_CACHE_KEY, _reverse_table, 60 * 60) # Cache for 1hr
+            cache.set(self._REVERSE_TABLE_CACHE_KEY, _reverse_table, 60 * 60)  # Cache for 1hr
         return _reverse_table
 
     # Used for both str and number
@@ -53,11 +54,12 @@ class _Permission(object):
 
 PERMISSIONS = _Permission()
 
+
 def merge_permissions(permissions):
     permission_collection = 0
     for permission in permissions:
         if permission not in PERMISSIONS:
-            raise ValueError, 'No such permission: %s' % permission
+            raise ValueError('No such permission: %s' % permission)
             # We save only number format
         if isinstance(permission, str):
             permission = getattr(PERMISSIONS, permission)
