@@ -1,6 +1,7 @@
-from django_eggplant import settings
+from django.conf import settings
+from ground_soil.lang import import_from_string
 from eggplant.constants.settings import AJAX_SIGNATURE_KEY_CLASS
-from eggplant.utils import import_from_string
+
 
 def ajax_signature_key(request):
     key_class_path = getattr(settings, AJAX_SIGNATURE_KEY_CLASS, None)
@@ -10,4 +11,4 @@ def ajax_signature_key(request):
     else:
         from eggplant.auth.signature import AjaxSignatureKey
 
-    return {'AJAX_REQUEST_SIGNATURE_KEY': AjaxSignatureKey().generator(request)}
\ No newline at end of file
+    return {'AJAX_REQUEST_SIGNATURE_KEY': AjaxSignatureKey().generator(request)}
