@@ -14,10 +14,13 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
+
 class AttributedDict(dict):
     def __getattr__(self, item):
-        if self.has_key(item): return self[item]
-        else: raise KeyError, item
+        if item in self:
+            return self[item]
+        else:
+            raise KeyError(item)
 
     def __setattr__(self, key, value):
         self[key] = value
