@@ -13,5 +13,3 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
-from eggplant.fabfile import deploy
-from eggplant.fabfile import server
\ No newline at end of file
