@@ -164,10 +164,7 @@ class TlsRedirectMiddleware(object):
             return self._redirect(request, secure)
 
     def _redirect(self, request, secure):
-        #protocol = secure and 'https' or 'http'
-        protocol = ''
-        if secure: protocol = 'https'
-        else: protocol = 'http'
+        protocol = 'https' if secure else 'http'
 
         newurl = '%s://%s%s' % (
             protocol, get_host(request), request.get_full_path(),)
