@@ -18,8 +18,8 @@ from django.db import models
 from eggplant import APP_LABEL
 from eggplant.utils.json import json_model_dict
 
-class DictModel(models.Model):
 
+class DictModel(models.Model):
     """
     An abstract model to make Models have dictionary-like interface
     """
@@ -88,8 +88,10 @@ class DictModel(models.Model):
 
         :return: a dictionary which is json serializable
         """
-        return json_model_dict(self.dict(json_serializable=True, summary=summary, **kwargs),
-            use_float_seconds=use_float_seconds)
+        return json_model_dict(
+            self.dict(json_serializable=True, summary=summary, **kwargs),
+            use_float_seconds=use_float_seconds
+        )
 
     class Meta:
         abstract = True
