@@ -14,12 +14,13 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
+
 def str2bool(raw_value):
     if raw_value.isdigit():
-        return raw_value!='0'
+        return raw_value != '0'
     elif raw_value.lower() in ('false', 'no', 'f', 'n'):
         return False
     elif raw_value.lower() in ('true', 'yes', 't', 'y'):
         return True
     else:
-        raise ValueError, '%s is not a valid boolean string.'
+        raise ValueError('%s is not a valid boolean string.')
