@@ -1,11 +1,12 @@
 import datetime
 from django.utils.timezone import is_naive
 from django.conf import settings
-from pytz import UTC, timezone
+from pytz import timezone
 from six import PY3
 
 CURRENT_TZ = timezone(settings.TIME_ZONE)
 
+
 def timestamp(raw_datetime, use_float_seconds=False):
     timestamp_format = '%s.%f' if use_float_seconds else '%s'
     if use_float_seconds:
@@ -22,11 +23,13 @@ def timestamp(raw_datetime, use_float_seconds=False):
 
     return result_type(target_datetime.strftime(timestamp_format))
 
+
 def time_to_seconds(time_object, use_float_seconds=False):
     seconds = time_object.hour*3600 + time_object.minute*60 + time_object.second
     if use_float_seconds: seconds += time_object.microsecond/1000000.0
     return seconds
 
+
 def time_to_utc_seconds(time_object, use_float_seconds=False):
     raw_seconds = time_to_seconds(time_object, use_float_seconds=use_float_seconds)
 
