@@ -14,13 +14,14 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from django.core.exceptions import ValidationError, ImproperlyConfigured
+from django.core.exceptions import ValidationError
 from eggplant.validators.number import range_validator
 
+
 def len_validator(target_value, operator):
     def validator(raw_value):
         try:
             range_validator(target_value, operator)(len(raw_value))
         except ValidationError:
-            raise ValidationError('The length of \'%s\' %s %s'%(raw_value, operator, target_value))
+            raise ValidationError('The length of \'{0}\' {1} {2}'.format(raw_value, operator, target_value))
     return validator
