@@ -17,6 +17,7 @@ limitations under the License.
 from django.core.exceptions import ValidationError, ImproperlyConfigured
 from eggplant.validators.string import is_integer
 
+
 def range_validator(target_value, operator):
     def validator(raw_value):
         raw_value = is_integer(raw_value)
@@ -24,13 +25,14 @@ def range_validator(target_value, operator):
         if operator not in ('==', '!=', '<=', '>=', '<', '>'):
             raise ImproperlyConfigured('Operator is invalid.')
 
-        if operator=='==' and raw_value==target_value: return
-        if operator=='!=' and raw_value!=target_value: return
-        if operator=='<=' and raw_value<=target_value: return
-        if operator=='>=' and raw_value>=target_value: return
-        if operator=='<'  and raw_value<target_value:  return
-        if operator=='>'  and raw_value>target_value:  return
+        if (operator == '==' and raw_value == target_value) or\
+           (operator == '!=' and raw_value != target_value) or\
+           (operator == '<=' and raw_value <= target_value) or\
+           (operator == '>=' and raw_value >= target_value) or\
+           (operator == '<' and raw_value < target_value) or\
+           (operator == '>' and raw_value > target_value):
+            return
 
-        raise ValidationError('(%s %s %s) is not valid.'%(raw_value, operator, target_value))
+        raise ValidationError('({0} {1} {2}) is not valid.'.format(raw_value, operator, target_value))
     return validator
 
