@@ -16,14 +16,14 @@ limitations under the License.
 
 from functools import update_wrapper
 import httplib
-from django import VERSION as DJANGO_VERSION
 from django.conf import settings
-from django.http import HttpResponse, QueryDict
+from django.http import HttpResponse
 from django.utils.decorators import classonlymethod
 from eggplant.constants import HTTP_METHOD
 from eggplant.constants.settings import HTTPS_ONLY
 from eggplant.views.exceptions import ViewError, MethodNotAllowedError
 
+
 class View(object):
     def __init__(self, *args, **kwargs):
         self.init_args = args
@@ -62,8 +62,7 @@ class View(object):
                 raise ViewError(httplib.BAD_REQUEST, 'This url accepts HTTPS only.')
 
             # Check allowed http methods
-            if request.method.upper() in HTTP_METHOD and \
-               hasattr(self, request.method.lower()):
+            if request.method.upper() in HTTP_METHOD and hasattr(self, request.method.lower()):
                 handler = getattr(self, request.method.lower())
             else:
                 raise MethodNotAllowedError(request)
@@ -93,6 +92,11 @@ class View(object):
 
         return self.response
 
+    def options(self, request, *args, **kwargs):
+        self.response = HttpResponse()
+        self.response['Allow'] = ', '.join([method for method in HTTP_METHOD if hasattr(self, method.lower())])
+        self.response['Content-Length'] = '0'
+
     def pre_handle(self, *args, **kwargs):
         pass
 
@@ -106,7 +110,6 @@ class View(object):
         pass
 
     def check_http_referer(self, referer, *args, **kwargs):
-        #raise exceptions.InvalidHttpRefererError
         pass
 
     def failed_to_authenticate_handler(self, error_obj):
