@@ -21,6 +21,8 @@ from django.core.exceptions import ImproperlyConfigured, FieldError
 from django.core.paginator import Paginator, EmptyPage
 from django.db.models import Q
 import yajl as json
+from eggplant.constants.defaults import EGGPLANT_MAX_PAGINATION_SIZE, EGGPLANT_DEFAULT_PAGINATION_SIZE
+from eggplant.constants.settings import MAX_PAGINATION_SIZE, DEFAULT_PAGINATION_SIZE
 from eggplant.utils.url import replace_querystring
 from eggplant.validators.number import range_validator
 from eggplant.validators.string import is_integer, is_positive_integer
@@ -28,11 +30,9 @@ from eggplant.views import exceptions
 from eggplant.views.api import APIView
 from eggplant.views.exceptions import ViewError
 from eggplant.views.decorators import validate_keys
-from eggplant.constants.settings import MAX_PAGINATION_SIZE, DEFAULT_PAGINATION_SIZE
-from eggplant.constants import defaults as eggplant_defaults
 
 FILTER_CACHE_KEY_PREFIX = 'com.wantoto.eggplant.views.api.model.filter'
-ORDER_CACHE_KEY_PREFIX  = 'com.wantoto.eggplant.views.api.model.order'
+ORDER_CACHE_KEY_PREFIX = 'com.wantoto.eggplant.views.api.model.order'
 
 SUPPORTED_FILTER_TYPES = [
     ('=',  '__exact'),
@@ -48,11 +48,12 @@ SUPPORTED_FILTER_TYPES = [
     ('$',  '__endswith'),
     ('i$', '__iendswith'),
     ('@', '__in'),
-    ]
+]
 SUPPORTED_FILTER_TYPES_DICT = dict(SUPPORTED_FILTER_TYPES)
 
 #-----------------------------------------------------------------------------------------------------------------------
 
+
 class ModelViewBase(APIView):
     # Permission
     ACCEPT_GET = True
@@ -77,6 +78,7 @@ class ModelViewBase(APIView):
 
 #-----------------------------------------------------------------------------------------------------------------------
 
+
 class ModelCollectionView(ModelViewBase):
     MODEL_COLLECTION_CLASS = None
     ORDERABLE_FIELDS = []
@@ -84,7 +86,7 @@ class ModelCollectionView(ModelViewBase):
     SKIP_DELIMITER_IN_FILTERS = False
     VALID_FILTERS_FOR_FIELDS = {}
 
-    DEFAULT_PAGE_SIZE = getattr(settings, DEFAULT_PAGINATION_SIZE, eggplant_defaults.EGGPLANT_DEFAULT_PAGINATION_SIZE)
+    DEFAULT_PAGE_SIZE = getattr(settings, DEFAULT_PAGINATION_SIZE, EGGPLANT_DEFAULT_PAGINATION_SIZE)
 
     #-------------------------------------------------------------------------------------------------------------------
     # Object Lifecycle
@@ -92,18 +94,19 @@ class ModelCollectionView(ModelViewBase):
     def __init__(self, *args, **kwargs):
         super(ModelCollectionView, self).__init__(*args, **kwargs)
 
-        if self.MODEL_COLLECTION_CLASS is None and kwargs.has_key('model_collection_class'):
+        if self.MODEL_COLLECTION_CLASS is None and 'model_collection_class' in kwargs:
             self.MODEL_COLLECTION_CLASS = kwargs['model_collection_class']
 
     #-------------------------------------------------------------------------------------------------------------------
     # Main methods
 
     @validate_keys(
-        (('page_size', 'limit'),
-          (is_positive_integer, range_validator(1, '>='),
-           range_validator(getattr(settings, MAX_PAGINATION_SIZE, eggplant_defaults.EGGPLANT_MAX_PAGINATION_SIZE), '<=')
-          )
-         ),
+        (
+            ('page_size', 'limit'),
+            (is_positive_integer,
+             range_validator(1, '>='),
+             range_validator(getattr(settings, MAX_PAGINATION_SIZE, EGGPLANT_MAX_PAGINATION_SIZE), '<='))
+        ),
         (('page_num', 'offset'), is_integer)
     )
     def get_collection(self, *args, **kwargs):
@@ -128,7 +131,7 @@ class ModelCollectionView(ModelViewBase):
         filter_cache_key = None
         if raw_filter is not None:
             # Get from cache
-            filter_cache_key = '%s.%s'%(FILTER_CACHE_KEY_PREFIX, raw_filter)
+            filter_cache_key = '{0}.{1}'.format(FILTER_CACHE_KEY_PREFIX, raw_filter)
             filters = cache.get(filter_cache_key)
         # Make new if cache is empty
         if raw_filter is not None and filters is None:
@@ -146,8 +149,8 @@ class ModelCollectionView(ModelViewBase):
                     query_components = [item.replace('\\', '') for item in re.split(r'((?<!\\)&|(?<!\\)\|)', and_pair)]
                 else:
                     query_components = re.split(r'(&|\|)', and_pair)
-                lookups = query_components[::2] # a,b,c ==> a,c
-                connectors = query_components[1::2] # a,b,c ==> b
+                lookups = query_components[::2]  # a,b,c ==> a,c
+                connectors = query_components[1::2]  # a,b,c ==> b
 
                 # Create each Q objects separated by '&' or '|'
                 q_objects = []
@@ -157,42 +160,49 @@ class ModelCollectionView(ModelViewBase):
                         field, filter_type, value = \
                             re.split(r'(?<!\\):', lookup) if self.SKIP_DELIMITER_IN_FILTERS else lookup.split(':')
                     except ValueError:
-                        raise exceptions.BadRequestError('Error filter format: %s'%lookup)
+                        raise exceptions.BadRequestError('Error filter format: {0}'.format(lookup))
 
                     # Field name and negate
                     negate = field.startswith('~')
-                    if negate: field = field[1:]
+                    if negate:
+                        field = field[1:]
 
                     # Check field name and filter type
-                    if not self.VALID_FILTERS_FOR_FIELDS.has_key(field):
-                        continue # Not a valid field
+                    if not field in self.VALID_FILTERS_FOR_FIELDS:
+                        continue  # Not a valid field
                     valid_filter_types = self.VALID_FILTERS_FOR_FIELDS[field]
                     if filter_type not in valid_filter_types:
-                        continue # not a valid filter type
+                        continue  # not a valid filter type
 
                     # Is value a list?
-                    if filter_type=='@':
+                    if filter_type == '@':
                         value = re.split(r'(?<!\\),', value) if self.SKIP_DELIMITER_IN_FILTERS else value.split(',')
 
                     # Create object
                     q_object = self.q_object_from_filter(field, filter_type, value, negate)
-                    if q_object is not None: q_objects.append(q_object)
+                    if q_object is not None:
+                        q_objects.append(q_object)
 
                 # Connect each Q objects in a ',' via & or |
                 final_q_object = None
                 for index, q in enumerate(q_objects):
-                    if index==0: final_q_object = q
+                    if index == 0:
+                        final_q_object = q
                     else:
-                        if connectors[index-1]=='&': final_q_object &= q
-                        elif connectors[index-1]=='|': final_q_object |= q
-                if final_q_object is not None: filters.append(final_q_object)
+                        if connectors[index - 1] == '&':
+                            final_q_object &= q
+                        elif connectors[index - 1] == '|':
+                            final_q_object |= q
+                if final_q_object is not None:
+                    filters.append(final_q_object)
             # Write back to cache
             cache.set(filter_cache_key, filters)
         # Apply filter to query set
         try:
-            if filters is not None and len(filters)!=0: query_set = query_set.filter(*filters)
+            if filters is not None and len(filters) != 0:
+                query_set = query_set.filter(*filters)
         except FieldError, e:
-            raise ImproperlyConfigured('Field is not valid: %s'%e.message)
+            raise ImproperlyConfigured('Field is not valid: {0}'.format(e.message))
         except ValueError:
             raise exceptions.BadRequestError('Error filter value')
 
@@ -201,7 +211,7 @@ class ModelCollectionView(ModelViewBase):
         order_cache_key = None
         orders = None
         if raw_order is not None:
-            order_cache_key = '%s.%s'%(ORDER_CACHE_KEY_PREFIX, raw_order)
+            order_cache_key = '{0}.{1}'.format(ORDER_CACHE_KEY_PREFIX, raw_order)
             orders = cache.get(order_cache_key)
         if raw_order is not None and orders is None:
             order_pairs = []
@@ -218,14 +228,15 @@ class ModelCollectionView(ModelViewBase):
             orders = self.order_list(query_set, order_pairs, *args, **kwargs)
             cache.set(order_cache_key, orders)
         try:
-            if orders is not None and len(orders)!=0: query_set = query_set.order_by(*orders)
+            if orders is not None and len(orders) != 0:
+                query_set = query_set.order_by(*orders)
         except FieldError, e:
-            raise ImproperlyConfigured('Field is not valid: %s'%e.message)
+            raise ImproperlyConfigured('Field is not valid: {0}'.format(e.message))
 
         meta_info = {}
         # Pagination
         default_page_size = self.DEFAULT_PAGE_SIZE
-        if self.request.GET.has_key('page_size') or self.request.GET.has_key('page_num'):
+        if 'page_size' in self.request.GET or 'page_num' in self.request.GET:
             page_size = int(self.request.GET.get('page_size', default_page_size))
             current_page_num = int(self.request.GET.get('page_num', 1))
 
@@ -233,13 +244,11 @@ class ModelCollectionView(ModelViewBase):
             try:
                 target_page = paginator.page(current_page_num)
             except EmptyPage:
-                raise ViewError(400, 'Requested page number (%s) is out of range. (Range: %s:%s)'%(
+                message = 'Requested page number ({0}) is out of range. (Range: {1[0]}:{1[-1]})'.format(
                     current_page_num,
-                    paginator.page_range[0],
-                    paginator.page_range[-1],
-                    ),
-                    reason='WPNOutOfPage'
+                    paginator.page_range,
                 )
+                raise ViewError(400, message, reason='WPNOutOfPage')
             queryset = target_page.object_list
 
             meta_info['pagination'] = {
@@ -265,7 +274,7 @@ class ModelCollectionView(ModelViewBase):
             result_offset = int(self.request.GET.get('offset', 0))
 
             item_count = query_set.count()
-            queryset = query_set[result_offset:result_offset+result_limit]
+            queryset = query_set[result_offset:(result_offset + result_limit)]
 
             meta_info['pagination'] = {
                 'item_count': item_count,
@@ -298,8 +307,6 @@ class ModelCollectionView(ModelViewBase):
 
     def get(self, *args, **kwargs):
         collection, queryset, meta_info = self.get_collection(*args, **kwargs)
-
-
         if self.show_meta_in_response(*args, **kwargs):
             result = {
                 'data': collection,
@@ -314,7 +321,7 @@ class ModelCollectionView(ModelViewBase):
     def post(self, *args, **kwargs):
         new_model = self.create_model(self.MODEL_COLLECTION_CLASS, *args, **kwargs)
         if new_model is None:
-            raise NotImplementedError, 'create_model method doesn\'t return a new model object.'
+            raise NotImplementedError('create_model method doesn\'t return a new model object.')
 
         model_presentation = self.model_presenter(*args, **kwargs)(new_model)
         self.response.content = json.dumps(model_presentation)
@@ -339,14 +346,15 @@ class ModelCollectionView(ModelViewBase):
     def queryset(self, *args, **kwargs):
         ModelClass = self.MODEL_COLLECTION_CLASS
         if ModelClass is None:
-            raise ImproperlyConfigured, 'Forget to set MODEL_CLASS for this ModelCollectionView'
+            raise ImproperlyConfigured('Forget to set MODEL_CLASS for this ModelCollectionView')
         return ModelClass.objects.all()
 
     def order_list(self, query_set, orders, *args, **kwargs):
         result_order_list = []
         for direction, raw_field in orders:
             order = self.field_for_order(raw_field, direction)
-            if order is None: continue
+            if order is None:
+                continue
             if isinstance(order, (list, tuple)):
                 result_order_list += order
             else:
@@ -354,18 +362,19 @@ class ModelCollectionView(ModelViewBase):
         return  result_order_list
 
     def q_object_from_filter(self, field, filter_type, value, negate):
-        q = Q(**{field+SUPPORTED_FILTER_TYPES_DICT[filter_type]: value})
-        if negate: return ~q
-        else: return q
+        arguments = {(field + SUPPORTED_FILTER_TYPES_DICT[filter_type]): value}
+        q = Q(**arguments)
+        return ~q if negate else q
 
     def field_for_order(self, order, direction, *args, **kwargs):
-        return order if direction==1 else '-'+order
+        return order if direction == 1 else '-' + order
 
     def model_presenter(self, *args, **kwargs):
         return lambda x: getattr(x, 'json_dict')(summary=True)
 
 #-----------------------------------------------------------------------------------------------------------------------
 
+
 class ModelView(ModelViewBase):
     # Model
     MODEL_CLASS = None
@@ -377,10 +386,10 @@ class ModelView(ModelViewBase):
     def __init__(self, *args, **kwargs):
         super(ModelView, self).__init__(*args, **kwargs)
 
-        if self.MODEL_CLASS is None and kwargs.has_key('model_class'):
+        if self.MODEL_CLASS is None and 'model_class' in kwargs:
             self.MODEL_CLASS = kwargs['model_class']
         if self.MODEL_NAME is None:
-            if kwargs.has_key('model_name'):
+            if 'model_name' in kwargs:
                 self.MODEL_NAME = kwargs['model_name']
             else:
                 self.MODEL_NAME = self.MODEL_CLASS.__name__
@@ -392,7 +401,7 @@ class ModelView(ModelViewBase):
         model_object = self.model_object(*args, **kwargs)
         model_presentation = self.model_presenter(*args, **kwargs)(model_object)
 
-        self.response.content = json.dumps(model_presentation, separators=(',',':'))
+        self.response.content = json.dumps(model_presentation)
 
     def put(self, *args, **kwargs):
         model_object = self.model_object(*args, **kwargs)
@@ -405,11 +414,11 @@ class ModelView(ModelViewBase):
             # Remove cached, let it update later
             delattr(self, '_model')
 
-        self.get(*args, **kwargs) # response content
+        self.get(*args, **kwargs)  # response content
 
     def delete(self, *args, **kwargs):
         model_object = self.model_object(*args, **kwargs)
-        self.get(*args, **kwargs) # response content
+        self.get(*args, **kwargs)  # response content
         model_object.delete()
 
     #-------------------------------------------------------------------------------------------------------------------
@@ -417,11 +426,12 @@ class ModelView(ModelViewBase):
 
     def model_object(self, *args, **kwargs):
         # kwargs must contains "model_id" (from url)
-        if hasattr(self, '_model'): return self._model
+        if hasattr(self, '_model'):
+            return self._model
 
         ModelClass = kwargs['model_class'] if 'model_class' in kwargs else self.MODEL_CLASS
         if ModelClass is None:
-            raise ImproperlyConfigured, 'Forget to set MODEL_CLASS for this ModelView'
+            raise ImproperlyConfigured('Forget to set MODEL_CLASS for this ModelView')
 
         try:
             model_object = self.get_model(ModelClass, *args, **kwargs)
