@@ -6,16 +6,16 @@ Came up in the IRC channel so I decided to post it.
 
 Easy enough to use.
 
->>> from ssldecorator import ssl_required
+from ssldecorator import ssl_required
 
->>> @ssl_required
-... def your_view(request):
-...     ''' your code here '''
+@ssl_required
+def your_view(request):
+    ''' your code here '''
 
 You can place a variable in your settings.py to change the SSL domain
 (ie, if you have SSL running on secure.yourdomain.com instead of www.yourdomain.com)
 
->>> SSL_DOMAIN = 'https://secure.yourdomain.com'
+SSL_DOMAIN = 'https://secure.yourdomain.com'
 
 Note: please include a proper URL. If https isn't used, the decorator will add it.
 """
@@ -24,6 +24,7 @@ import urlparse
 from django.conf import settings
 from django.http import HttpResponseRedirect
 
+
 def ssl_required(view_func):
     def _checkssl(request, *args, **kwargs):
         if not settings.DEBUG and not request.is_secure():
@@ -38,4 +39,4 @@ def ssl_required(view_func):
             return HttpResponseRedirect(url_str)
 
         return view_func(request, *args, **kwargs)
-    return _checkssl
\ No newline at end of file
+    return _checkssl
