@@ -13,10 +13,11 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
-
+from django.core.exceptions import ImproperlyConfigured
 from django.shortcuts import render
 from eggplant.views import View
 
+
 class HTMLView(View):
     def __init__(self, *args, **kwargs):
         super(HTMLView, self).__init__(*args, **kwargs)
@@ -30,4 +31,4 @@ class HTMLView(View):
             context.update(self.request.GET)
             self.response = render(self.request, self.template_name, context)
         else:
-            raise ValueError, 'Template name is undefined.'
+            raise ImproperlyConfigured('Template name is undefined.')
